@@ -1,5 +1,5 @@
 from django import forms
-from coop_cms.models import NavType, NavNode, Newsletter, NewsletterSending, Link, Document
+from coop_cms.models import NavType, NavNode, Newsletter, NewsletterSending, Link, Document, Fragment
 from django.contrib.contenttypes.models import ContentType
 from settings import get_navigable_content_types
 from django.core.exceptions import ValidationError
@@ -14,11 +14,7 @@ from django.core.urlresolvers import reverse
 from coop_cms.utils import dehtml
 from datetime import datetime
 from django.utils.timezone import now as dt_now
-try:
-    from chosen.widgets import ChosenSelectMultiple
-except ImportError:
-    print "chosen missing"
-    pass
+from coop_cms.widgets import ChosenSelectMultiple
 
 class NavTypeForm(forms.ModelForm):
     def __init__(self, *args, **kwargs):
@@ -63,7 +59,7 @@ class ArticleForm(AlohaEditableModelForm):
 
     class Meta:
         model = get_article_class()
-        fields = ('title', 'content', 'logo')
+        fields = ('title', 'subtitle', 'content', 'logo')
         no_aloha_widgets = ('logo',)
 
     def set_logo_size(self, logo_size=None):
@@ -211,6 +207,8 @@ class ArticleSettingsForm(WithNavigationModelForm):
         if not summary:
             summary = dehtml(article.content)[:400]
         initials.update({'summary': summary})
+        initials.update({'publication_date': article.publication_date.strftime("%Y-%m-%d %H:%M:%S")})
+        
         kwargs['initial'] = initials
         super(ArticleSettingsForm, self).__init__(*args, **kwargs)
 
@@ -333,6 +331,8 @@ class NewsletterTemplateForm(forms.Form):
         else:
             self.fields["template"] = forms.CharField()
         self.fields["template"].initial = newsletter.template
+        
+        
 
 class NewsletterAdminForm(forms.ModelForm):
 
@@ -361,4 +361,44 @@ class NewsletterAdminForm(forms.ModelForm):
         css = {
             'all': ('css/admin-tricks.css',),
         }
-        js = ()
\ No newline at end of file
+        js = ()
+        
+class AddFragmentForm(forms.ModelForm):
+
+    class Meta:
+        model = Fragment
+        fields = ('type', 'name', 'position', 'filter')
+        
+    def __init__(self, data=None, *args, **kwargs):
+        super(AddFragmentForm, self).__init__(data, *args, **kwargs)
+        self.fields['filter'].widget = forms.HiddenInput()
+        
+class EditFragmentForm(forms.ModelForm):
+    delete_me = forms.BooleanField(label=_(u"delete"), required=False)
+
+    class Meta:
+        model = Fragment
+        fields = ('type', 'filter', 'name', 'css_class', 'position')
+        widgets = {
+            "type": forms.HiddenInput(),
+            "filter": forms.HiddenInput(),
+        }
+        
+    def __init__(self, *args, **kwargs):
+        super(EditFragmentForm, self).__init__(*args, **kwargs)
+        choices = [('', '')]+[(x, x) for x in self.instance.type.allowed_css_classes.split(',')]
+        self.fields['css_class'].widget = forms.Select(choices=choices)
+        
+    def clean_css_class(self):
+        val = self.cleaned_data['css_class']
+        if val:
+            if not val in self.instance.type.allowed_css_classes.split(','):
+                val = u""
+        return val
+        
+    def save(self, *args, **kwargs):
+        if self.cleaned_data['delete_me']:
+            self.instance.delete()
+            return None
+        return super(EditFragmentForm, self).save(*args, **kwargs)
+    
\ No newline at end of file
