@@ -18,7 +18,8 @@ from django.core.exceptions import ValidationError
 # from html_field import html_cleaner
 from coop_cms.settings import get_article_class, get_article_logo_size, get_newsletter_item_classes
 from coop_cms.settings import get_navtree_class, is_localized, COOP_CMS_NAVTREE_CLASS, get_article_templates
-from coop_cms.settings import get_default_logo
+from coop_cms.settings import get_default_logo, is_requestprovider_installed
+from coop_cms.utils import dehtml
 from django.contrib.staticfiles import finders
 from django.core.files import File
 from django.db.models.signals import pre_delete, post_save
@@ -117,6 +118,17 @@ class NavNode(models.Model):
         if self.content_object:
             return self.content_object.get_absolute_url()
         return None
+    
+    def is_active_node(self):
+        url = self.get_absolute_url()
+        if url and is_requestprovider_installed():
+            from gadjo.requestprovider.signals import get_request
+            try:
+                http_request = get_request()
+                return http_request and http_request.path == url
+            except IndexError:
+                pass
+        return False
 
     def get_content_name(self):
         return self.content_type.model_class()._meta.verbose_name
@@ -137,6 +149,9 @@ class NavNode(models.Model):
 
     def has_children(self):
         return self.get_children(True).count()
+    
+    def get_children_navigation(self):
+        return self.get_children(True)
 
     def get_siblings(self, in_navigation=None):
         nodes = NavNode.objects.filter(parent=self.parent).order_by("ordering")
@@ -189,33 +204,40 @@ class NavNode(models.Model):
             return t.render(Context({'node': self}))
         else:
             return u''
+        
+    #def render(self, template_name):
+    #    t = get_template(template_name)
+    #    return t.render(Context({'node': self}))
 
-    def as_navigation(self, li_template=None, css_class="", ul_template=None, li_args=None):
+    def as_navigation(self, li_template=None, css_class="", ul_template=None, li_args=None, active_class="active-node"):
         #Display the node and his children as nested ul and li html tags.
         #li_template is a custom template that can be passed
 
         if not self.in_navigation:
             return ""
 
-        children_li = [child.as_navigation(li_template) for child in self.get_children(in_navigation=True)]
+        children_li = [child.as_navigation(li_template, css_class) for child in self.get_children(in_navigation=True)]
         ul_format = self._get_ul_format(ul_template)
         children_html = ul_format.format(u''.join(children_li)) if children_li else ""
         args = self._get_li_args(li_args)
-        if args:
-            css_class = " "+args
-        return u'<li{0}>{1}{2}</li>'.format(css_class, self._get_li_content(li_template), children_html)
+        if args.find("class=")<0:
+            css_class = u'class="{0} {1}"'.format(css_class, active_class if self.is_active_node() else "")
+        else:
+            css_class=""
+        return u'<li {0} {1}>{2}{3}</li>'.format(
+            css_class, args, self._get_li_content(li_template), children_html)
 
     def as_breadcrumb(self, li_template=None, css_class=""):
         html = self.parent.as_breadcrumb(li_template) if self.parent else u""
-        return html + u'<li{0}>{1}</li>'.format(css_class, self._get_li_content(li_template))
+        return html + u'<li class="{0}">{1}</li>'.format(css_class, self._get_li_content(li_template))
 
     def children_as_navigation(self, li_template=None, css_class=""):
-        children_li = [u'<li{0}>{1}</li>'.format(css_class, child._get_li_content(li_template))
+        children_li = [u'<li class="{0}">{1}</li>'.format(css_class, child._get_li_content(li_template))
             for child in self.get_children(in_navigation=True)]
         return  u''.join(children_li)
 
     def siblings_as_navigation(self, li_template=None, css_class=""):
-        siblings_li = [u'<li{0}>{1}</li>'.format(css_class, sibling._get_li_content(li_template))
+        siblings_li = [u'<li class="{0}">{1}</li>'.format(css_class, sibling._get_li_content(li_template))
             for sibling in self.get_siblings(in_navigation=True)]
         return  u''.join(siblings_li)
 
@@ -268,9 +290,16 @@ class ArticleCategory(models.Model):
 
     def __unicode__(self):
         return self.name
+    
+    def can_view_category(self, user):
+        return True
 
     def get_absolute_url(self):
         return reverse('coop_cms_articles_category', args=[self.slug])
+    
+    def get_articles_qs(self):
+        return get_article_class().objects.filter(
+            category=self, publication=BaseArticle.PUBLISHED).order_by('publication_date')
 
     class Meta:
         verbose_name = _(u'article category')
@@ -341,6 +370,7 @@ class BaseArticle(BaseNavigable):
     #title = HTMLField(title_cleaner, verbose_name=_(u'title'), default=_('Page title'))
     #content = HTMLField(content_cleaner, verbose_name=_(u'content'), default=_('Page content'))
     title = models.TextField(_(u'title'), default='', blank=True)
+    subtitle = models.TextField(_(u'subtitle'), default='', blank=True)
     content = models.TextField(_(u'content'), default='', blank=True)
     publication = models.IntegerField(_(u'publication'), choices=PUBLICATION_STATUS, default=PUBLISHED)
     template = models.CharField(_(u'template'), max_length=200, default='', blank=True)
@@ -352,7 +382,7 @@ class BaseArticle(BaseNavigable):
     homepage_for_site = models.ForeignKey(Site, verbose_name=_(u'Homepage for site'), blank=True, null=True, default=None, related_name="homepage_article")
     headline = models.BooleanField(_(u"Headline"), default=False, help_text=_(u'Make this article appear on the home page'))
     publication_date = models.DateTimeField(_(u"Publication date"), default=datetime.now())
-    sites = models.ManyToManyField(Site, verbose_name=_(u'site'), default=settings.SITE_ID)
+    sites = models.ManyToManyField(Site, verbose_name=_(u'site'), default=[settings.SITE_ID])
     
     @property
     def is_homepage(self):
@@ -360,10 +390,13 @@ class BaseArticle(BaseNavigable):
             return self.homepage_for_site.id == settings.SITE_ID
         return False
     
+    def is_draft(self):
+        return self.publication == BaseArticle.DRAFT
+    
     def next_in_category(self):
         if self.category:
             try:
-                return get_article_class().objects.filter(category=self.category,
+                return get_article_class().objects.filter(category=self.category, publication=BaseArticle.PUBLISHED,
                     publication_date__gt=self.publication_date).order_by('publication_date')[0]
             except IndexError:
                 pass
@@ -461,6 +494,8 @@ class BaseArticle(BaseNavigable):
         return ret
     
     def get_unique_slug(self, slug_field, title):
+        #no html in title
+        title = dehtml(title)
         slug = slugify(title)
         next, origin_slug = 2, slug
         while True:
@@ -555,7 +590,7 @@ class Link(BaseNavigable):
         return self.url
 
     def __unicode__(self):
-        return self.title
+        return dehtml(self.title)
 
     class Meta:
         verbose_name = _(u"link")
@@ -798,6 +833,70 @@ class Alias(models.Model):
     
     def __unicode__(self):
         return self.path
+    
+class FragmentType(models.Model):
+    name = models.CharField(max_length=100, db_index=True, verbose_name=_(u"name"))
+    allowed_css_classes = models.CharField(max_length=200, verbose_name=_(u"allowed css classes"), default="",
+        help_text=_(u"the css classed proposed when editing a fragment. It must be separated by comas"))
+    
+    class Meta:
+        verbose_name = _(u'Fragment type')
+        verbose_name_plural = _(u'Fragment types')
+        
+    def __unicode__(self):
+        return self.name
+
+class FragmentFilter(models.Model):
+    extra_id = models.CharField(max_length=100, db_index=True, verbose_name=_(u"extra_id"))
+    
+    class Meta:
+        verbose_name = _(u'Fragment filter')
+        verbose_name_plural = _(u'Fragment filters')
+        
+    def __unicode__(self):
+        return self.extra_id
+    
+class Fragment(models.Model):
+    type = models.ForeignKey(FragmentType, verbose_name=_(u'fragment type'))
+    name = models.CharField(max_length=100, db_index=True, verbose_name=_(u'name'))
+    css_class = models.CharField(max_length=100, default=u"", blank=True, verbose_name=_(u'CSS class'))
+    position = models.IntegerField(verbose_name=_("position"), default=0)
+    content = models.TextField(default=u"", blank=True, verbose_name=_(u'content'))
+    filter = models.ForeignKey(FragmentFilter, verbose_name=_(u'fragment filter'), blank=True, null=True, default=None)
+    
+    class Meta:
+        verbose_name = _(u'Fragment')
+        verbose_name_plural = _(u'Fragment')
+        ordering = ("position", "id")
+        
+    def _can_change(self, user):
+        ct = ContentType.objects.get_for_model(get_article_class())
+        perm = '{0}.change_{1}'.format(ct.app_label, ct.model)
+        return user.has_perm(perm)
+
+    def can_add_fragment(self, user):
+        ct = ContentType.objects.get_for_model(Fragment)
+        perm = '{0}.add_{1}'.format(ct.app_label, ct.model)
+        return user.has_perm(perm)
+
+    def can_edit_fragment(self, user):
+        ct = ContentType.objects.get_for_model(Fragment)
+        perm = '{0}.change_{1}'.format(ct.app_label, ct.model)
+        return user.has_perm(perm)
+        
+    def save(self, *args, **kwargs):
+        if not self.id and not self.position:
+            max_position = Fragment.objects.filter(type=self.type, filter=self.filter).aggregate(Max('position'))['position__max'] or 0
+            self.position = max_position + 1
+            
+        return super(Fragment, self).save(*args, **kwargs)
+        
+    def __unicode__(self):
+        return u"{0} {1} {2}".format(self.type, self.position, self.name)
+    
+    
+    
+
 
 
     
\ No newline at end of file
