@@ -31,6 +31,8 @@ urlpatterns = patterns('coop_cms.views',
     url(r'sitemap/$', 'tree_map', name="default_site_map"),
     url(r'articles/(?P<slug>[-\w]+)/$', 'articles_category', name="coop_cms_articles_category"),
     url(r'cms/change-language/$', 'change_language', name='coop_cms_change_language'),
+    url(r'^cms/fragments/add/$', 'add_fragment', name='coop_cms_add_fragment'),
+    url(r'^cms/fragments/edit/$', 'edit_fragments', name='coop_cms_edit_fragments'),
 )
 
 if 'coop_cms.apps.rss_sync' in settings.INSTALLED_APPS:
